@@ -10,11 +10,20 @@ Usage::
     client: KafkaClient = boto3.client("kafka")
     ```
 """
-import sys
 from typing import IO, Any, Dict, List, Type, Union, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_kafka.literals import (
+    EnhancedMonitoring,
+    ListClusterOperationsPaginatorName,
+    ListClustersPaginatorName,
+    ListConfigurationRevisionsPaginatorName,
+    ListConfigurationsPaginatorName,
+    ListKafkaVersionsPaginatorName,
+    ListNodesPaginatorName,
+    ListScramSecretsPaginatorName,
+)
 from mypy_boto3_kafka.paginator import (
     ListClusterOperationsPaginator,
     ListClustersPaginator,
@@ -62,12 +71,6 @@ from mypy_boto3_kafka.type_defs import (
     UpdateMonitoringResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("KafkaClient",)
 
 
@@ -127,9 +130,7 @@ class KafkaClient:
         ClientAuthentication: "ClientAuthenticationTypeDef" = None,
         ConfigurationInfo: "ConfigurationInfoTypeDef" = None,
         EncryptionInfo: "EncryptionInfoTypeDef" = None,
-        EnhancedMonitoring: Literal[
-            "DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER", "PER_TOPIC_PER_PARTITION"
-        ] = None,
+        EnhancedMonitoring: EnhancedMonitoring = None,
         OpenMonitoring: OpenMonitoringInfoTypeDef = None,
         LoggingInfo: "LoggingInfoTypeDef" = None,
         Tags: Dict[str, str] = None,
@@ -330,9 +331,7 @@ class KafkaClient:
         self,
         ClusterArn: str,
         CurrentVersion: str,
-        EnhancedMonitoring: Literal[
-            "DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER", "PER_TOPIC_PER_PARTITION"
-        ] = None,
+        EnhancedMonitoring: EnhancedMonitoring = None,
         OpenMonitoring: OpenMonitoringInfoTypeDef = None,
         LoggingInfo: "LoggingInfoTypeDef" = None,
     ) -> UpdateMonitoringResponseTypeDef:
@@ -342,21 +341,21 @@ class KafkaClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_cluster_operations"]
+        self, operation_name: ListClusterOperationsPaginatorName
     ) -> ListClusterOperationsPaginator:
         """
         [Paginator.ListClusterOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
+    def get_paginator(self, operation_name: ListClustersPaginatorName) -> ListClustersPaginator:
         """
         [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListClusters)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_configuration_revisions"]
+        self, operation_name: ListConfigurationRevisionsPaginatorName
     ) -> ListConfigurationRevisionsPaginator:
         """
         [Paginator.ListConfigurationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
@@ -364,7 +363,7 @@ class KafkaClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_configurations"]
+        self, operation_name: ListConfigurationsPaginatorName
     ) -> ListConfigurationsPaginator:
         """
         [Paginator.ListConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
@@ -372,21 +371,21 @@ class KafkaClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_kafka_versions"]
+        self, operation_name: ListKafkaVersionsPaginatorName
     ) -> ListKafkaVersionsPaginator:
         """
         [Paginator.ListKafkaVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
+    def get_paginator(self, operation_name: ListNodesPaginatorName) -> ListNodesPaginator:
         """
         [Paginator.ListNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListNodes)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_scram_secrets"]
+        self, operation_name: ListScramSecretsPaginatorName
     ) -> ListScramSecretsPaginator:
         """
         [Paginator.ListScramSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
